import React from 'react';
import PropTypes from 'prop-types';
import DateTimePicker from '../../../DateTimePicker/DateTimePicker';

class DateFilter extends React.Component {
    state = {
        secondDateBoxesShowing: false,
    }

    render() {
        const { secondDateBoxesShowing } = this.state;
        const {
            width,
            filterStyle,
            selectStyles,
            field,
            format,
            textBoxes,
            selectedFilterOption,
        } = this.props;

        let mode = 'date';
        let dateTimeFormat = 'yyyy/M/dd';

        if (format) {
            switch (format) {
                case 'date':
                    mode = 'date';
                    dateTimeFormat = 'yyyy/M/dd';
                    break;
                case 'time':
                    mode = 'time';
                    dateTimeFormat = 'HH:mm';
                    break;
                case 'date-time':
                    mode = 'datetime';
                    dateTimeFormat = 'yyyy/M/dd HH:mm';
                    break;
                default:
                    mode = 'date';
                    break;
            }
        }

        const selectOptions = [
            {
                value: 'equals',
                caption: 'Equals',
            },
            {
                value: 'greaterThan',
                caption: 'Greater than',
            },
            {
                value: 'lessThan',
                caption: 'Less than',
            },
            {
                value: 'notEqual',
                caption: 'Not equal',
            },
            {
                value: 'inRange',
                caption: 'In range',
            },
        ];

        return (
            <div style={ {
                width,
                ...filterStyle,
            } }>
                { /* eslint-disable-next-line jsx-a11y/no-onchange */ }
                <select
                    onChange={ this.handleSelectChange }
                    style={ selectStyles }
                    className="ag-filter-select"
                    value={ selectedFilterOption[field] }
                    ref={ (ref) => this.dateSelect = ref }>
                    { selectOptions.map((option) => (
                        <option
                            key={ option.value }
                            value={ option.value }>
                            { option.caption }
                        </option>
                    )) }
                </select>
                <DateTimePicker
                    is24Hour
                    selectedDate={ textBoxes[field] ? textBoxes[field].date : null }
                    ref={ (ref) => { this.date = ref ? ref.state.selectedDate : ref; } }
                    onChange={ this.handleDateChange }
                    format={ dateTimeFormat }
                    mode={ mode } />
                {
                    (secondDateBoxesShowing || selectedFilterOption[field] === 'inRange') ?
                        <div style={ {
                            display: 'block',
                            paddingTop: '4px',
                        } }>
                            <DateTimePicker
                                is24Hour
                                selectedDate={ textBoxes[field] ? textBoxes[field].date2 : null }
                                ref={ (ref) => { this.date2 = ref ? ref.state.selectedDate : ref ; } }
                                onChange={ this.handleDateChange }
                                format={ dateTimeFormat }
                                mode={ mode } />
                        </div>
                        :
                        null
                }
            </div>
        );
    }

    /** On selection of inRange option updates state to show second date-time picker */
    handleSelectChange = () => {
        this.setState({ secondDateBoxesShowing: this.dateSelect.value === 'inRange' });
        this.handleDateChange();
    }

    /** Handle changes in date-time and passes on the value(s) */
    handleDateChange = () => {
        const {
            field,
            onDateChanged,
        } = this.props;

        const {
            secondDateBoxesShowing,
        } = this.state;

        const textBoxes = {
            [field]: {
                date: this.date,
                date2: secondDateBoxesShowing || this.dateSelect.value === 'inRange' ? this.date2 : null,
            },
        };
        onDateChanged(field, textBoxes, this.dateSelect.value);
    };
};

DateFilter.propTypes = {
    /** Column width */
    width: PropTypes.string,

    /** Column identifier (field name) */
    field: PropTypes.string,

    /** Filter text values for each field/column */
    textBoxes: PropTypes.object,

    /** Selected filter option, e.g. contains, equals etc. */
    selectedFilterOption: PropTypes.object,

    /** Method to pass on value. */
    onDateChanged: PropTypes.func,

    /** Style for the datetime filter */
    filterStyle: PropTypes.object,

    /** Style for select element */
    selectStyles: PropTypes.object,

    /** Data format for column. */
    format: PropTypes.string,
};

export default DateFilter;
